@@ -48,6 +48,13 @@ public:
         Password = 1
     };
 
+    enum AuthStatus {
+        None = -1,
+        WaitingInput,
+        Authenticating,
+        Completed,
+    };
+
     AuthDialog(const QString &message,
                const QString &iconName);
     ~AuthDialog();
@@ -66,12 +73,17 @@ public:
 
     PolkitQt1::Identity selectedAdminUser() const;
 
+    bool hasOpenSecurity();
+    bool hasSecurityHighLever(QString userName);
+    void setInAuth(AuthStatus authStatus);
+
 signals:
     void adminUserSelected(PolkitQt1::Identity);
 
 private:
     void initUI();
     int getLockLimitTryNum();
+    bool passwordIsExpired(PolkitQt1::Identity identity);
 
 private slots:
     void on_userCB_currentIndexChanged(int index);
@@ -91,5 +103,6 @@ private:
     void showErrorTip();
 
     QString m_errorMsg;
+    AuthStatus m_authStatus;
 };
 #endif // AUTHDIALOG_H
