@@ -32,6 +32,7 @@
 #include "AuthDialog.h"
 #include "polkit1authagent_adaptor.h"
 #include "pluginmanager.h"
+#include "policykitlistener.h"
 
 #define USE_DEEPIN_AUTH "useDeepinAuth"
 
@@ -107,12 +108,6 @@ void PolicyKitListener::initiateAuthentication(const QString &actionId,
     m_dialog = new AuthDialog(message, iconName);
     m_dialog->setAttribute(Qt::WA_DeleteOnClose);
     initDialog(actionId);
-
-    if (identities.length() == 1) {
-        createSessionForId(identities[0]);
-    } else {
-        createSessionForId(m_dialog.data()->selectedAdminUser());
-    }
 }
 
 void PolicyKitListener::initDialog(const QString &actionId)
@@ -188,9 +183,10 @@ void PolicyKitListener::request(const QString &request, bool echo)
 
     qDebug() << "session request: " << request;
 
-    if (m_dialog && !request.isEmpty())
+    if (m_dialog && !request.isEmpty()) {
         m_dialog.data()->setAuthInfo(request);
-
+        m_dialog.data()->setInAuth(AuthDialog::WaitingInput);
+    }
 }
 
 void PolicyKitListener::completed(bool gainedAuthorization)
@@ -202,10 +198,13 @@ void PolicyKitListener::completed(bool gainedAuthorization)
         m_gainedAuthorization = true;
     m_showInfoSuccess = false;
 
+#ifdef USE_DEEPIN_POLKIT
     if (m_exAuth) {
         m_session.data()->authCtrl(AUTH_CLOSE, -1);
     }
+#endif
     finishObtainPrivilege();
+    m_dialog.data()->setInAuth(AuthDialog::Completed);
 }
 
 void PolicyKitListener::showError(const QString &text)
@@ -242,13 +241,16 @@ void PolicyKitListener::exAuthInfo(bool isMfa, QList<int> &authTypes) {
     m_exAuth = true;
     m_isMfa = isMfa;
 
+#ifdef USE_DEEPIN_POLKIT
     if (!isMfa) {
         m_session.data()->authCtrl(AUTH_START, -1);
     }
+#endif
 }
 
 void PolicyKitListener::dialogAccepted()
 {
+    m_dialog.data()->setInAuth(AuthDialog::Authenticating);
     m_session->setResponse(m_dialog->password());
 }
 
@@ -271,7 +273,11 @@ void PolicyKitListener::createSessionForId(const PolkitQt1::Identity &identity)
     }
     // We will create new session only when some user is selected
     if (m_selectedUser.isValid()) {
+#ifdef USE_DEEPIN_POLKIT
         m_session = new Session(m_selectedUser, m_cookie, m_result, &m_details);
+#else
+        m_session = new Session(m_selectedUser, m_cookie, m_result);
+#endif
 
         connect(m_session.data(), &Session::request, this,
                 &PolicyKitListener::request);
@@ -281,11 +287,12 @@ void PolicyKitListener::createSessionForId(const PolkitQt1::Identity &identity)
                 &PolicyKitListener::showError);
         connect(m_session.data(), &Session::showInfo, this,
                 &PolicyKitListener::showInfo);
+#ifdef USE_DEEPIN_POLKIT
         connect(m_session.data(), &Session::exAuthStatus, this,
                 &PolicyKitListener::exAuthStatus);
         connect(m_session.data(), &Session::exAuthInfo, this,
                 &PolicyKitListener::exAuthInfo);
-
+#endif
         m_session->initiate();
     }
 }
@@ -294,14 +301,22 @@ void PolicyKitListener::fillResult()
 {
     if (!m_session.isNull()) {
         if (m_wasCancelled) {
+#ifdef USE_DEEPIN_POLKIT
             m_session.data()->result()->setCancel("aciton cancel");
+#else
+            m_session->result()->setError("action cancel");
+#endif
         } else if (!m_gainedAuthorization) {
             m_session.data()->result()->setError("password error");
         }
         m_session.data()->result()->setCompleted();
     } else {
         if (m_wasCancelled) {
+#ifdef USE_DEEPIN_POLKIT
             m_result->setCancel("action cancel");
+#else
+            m_result->setError("action cancel");
+#endif
         } else if (!m_gainedAuthorization) {
             m_result->setError("password error");
         }
